Conversation Summary Memory
Uses LLM to automatically summarize conversation history, solving the long conversation token explosion problem.
Structs
- Conversation
Summary Memory - Conversation Summary Memory
Conversation Summary Memory
Uses LLM to automatically summarize conversation history, solving the long conversation token explosion problem.